@@ -165,6 +165,13 @@ static void     evd_dbus_bridge_on_reg_obj_call_method (GObject     *object,
                                                         guint64      serial,
                                                         gpointer     user_data);
 
+#ifndef ENABLE_TESTS
+void            evd_dbus_bridge_process_msg            (EvdDBusBridge *self,
+                                                        GObject       *object,
+                                                        const gchar   *msg,
+                                                        gsize          length);
+#endif /* ENABLE_TESTS */
+
 static void
 evd_dbus_bridge_class_init (EvdDBusBridgeClass *class)
 {
@@ -1318,6 +1325,10 @@ evd_dbus_bridge_emit_signal (EvdDBusBridge *self,
                                   NULL);
       goto out;
     }
+  else
+    {
+      g_variant_ref_sink (signal_args_variant);
+    }
 
   if (! evd_dbus_agent_emit_signal (obj,
                                     subject,
@@ -1414,16 +1425,6 @@ evd_dbus_bridge_add_transport (EvdDBusBridge *self, EvdTransport *transport)
                     self);
 }
 
-#ifdef ENABLE_TESTS
-
-void
-evd_dbus_bridge_track_object (EvdDBusBridge *self, GObject *object)
-{
-  evd_dbus_agent_set_object_vtable (object,
-                                    &self->priv->agent_vtable,
-                                    self);
-}
-
 void
 evd_dbus_bridge_process_msg (EvdDBusBridge *self,
                              GObject       *object,
@@ -1519,6 +1520,16 @@ evd_dbus_bridge_process_msg (EvdDBusBridge *self,
   g_variant_unref (variant_msg);
 }
 
+#ifdef ENABLE_TESTS
+
+void
+evd_dbus_bridge_track_object (EvdDBusBridge *self, GObject *object)
+{
+  evd_dbus_agent_set_object_vtable (object,
+                                    &self->priv->agent_vtable,
+                                    self);
+}
+
 void
 evd_dbus_bridge_set_send_msg_callback (EvdDBusBridge          *self,
                                        EvdDBusBridgeSendMsgCb  callback,
