@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010, Igalia S.L.
+ * Copyright (C) 2009/2010/2011/2012, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -218,6 +218,8 @@ evd_transport_receive_internal (EvdTransport *self,
 {
   EvdTransportPeerMessage *msg;
 
+  g_object_ref (peer);
+
   msg = g_object_get_data (G_OBJECT (peer), PEER_MSG_KEY);
   if (msg == NULL)
     {
@@ -240,6 +242,8 @@ evd_transport_receive_internal (EvdTransport *self,
     }
   msg->buffer = NULL;
   msg->size = 0;
+
+  g_object_unref (peer);
 }
 
 static gboolean
@@ -332,13 +336,51 @@ evd_transport_accept_peer_internal (EvdTransport *self, EvdPeer *peer)
 
   peer_manager = EVD_TRANSPORT_GET_INTERFACE (self)->peer_manager;
 
-  evd_peer_manager_add_peer (peer_manager, peer);
+  if (evd_peer_manager_lookup_peer (peer_manager,
+                                    evd_peer_get_id (peer)) == NULL)
+    {
+      evd_peer_manager_add_peer (peer_manager, peer);
+      /* By design, only EvdPeerManager should hold a reference to
+         a peer, so after adding a peer we should drop our reference */
+      g_object_unref (peer);
 
-  evd_transport_notify_new_peer (self, peer);
+      evd_transport_notify_new_peer (self, peer);
+    }
 
   return TRUE;
 }
 
+static gboolean
+send_frame (EvdTransport    *self,
+            EvdPeer         *peer,
+            const gchar     *buffer,
+            gsize            size,
+            EvdMessageType   type,
+            GError         **error)
+{
+  g_return_val_if_fail (EVD_IS_TRANSPORT (self), FALSE);
+  g_return_val_if_fail (EVD_IS_PEER (peer), FALSE);
+
+  if (! EVD_TRANSPORT_GET_INTERFACE (self)->send (self,
+                                                  peer,
+                                                  buffer,
+                                                  size,
+                                                  type,
+                                                  NULL)
+      && ! evd_peer_push_message (peer,
+                                  buffer,
+                                  size,
+                                  type,
+                                  error))
+    {
+      return FALSE;
+    }
+  else
+    {
+      return TRUE;
+    }
+}
+
 /* public methods */
 
 gboolean
@@ -348,22 +390,7 @@ evd_transport_send (EvdTransport  *self,
                     gsize          size,
                     GError       **error)
 {
-  g_return_val_if_fail (EVD_IS_TRANSPORT (self), FALSE);
-  g_return_val_if_fail (EVD_IS_PEER (peer), FALSE);
-
-  if (! EVD_TRANSPORT_GET_INTERFACE (self)->send (self,
-                                                  peer,
-                                                  buffer,
-                                                  size,
-                                                  NULL)
-      && ! evd_peer_backlog_push_frame (peer, buffer, size, error))
-    {
-      return FALSE;
-    }
-  else
-    {
-      return TRUE;
-    }
+  return send_frame (self, peer, buffer, size, EVD_MESSAGE_TYPE_BINARY, error);
 }
 
 gboolean
@@ -374,12 +401,9 @@ evd_transport_send_text (EvdTransport  *self,
 {
   gsize size;
 
-  g_return_val_if_fail (EVD_IS_TRANSPORT (self), FALSE);
-  g_return_val_if_fail (EVD_IS_PEER (peer), FALSE);
-
   size = strlen (text);
 
-  return evd_transport_send (self, peer, text, size, error);
+  return send_frame (self, peer, text, size, EVD_MESSAGE_TYPE_TEXT, error);
 }
 
 /**
@@ -492,6 +516,11 @@ evd_transport_close_peer (EvdTransport  *self,
   g_object_unref (peer);
 }
 
+/**
+ * evd_transport_create_new_peer:
+ *
+ * Returns: (transfer full):
+ **/
 EvdPeer *
 evd_transport_create_new_peer (EvdTransport *self)
 {
@@ -506,11 +535,21 @@ evd_transport_create_new_peer (EvdTransport *self)
   return iface->create_new_peer (self);
 }
 
+/**
+ * evd_transport_lookup_peer:
+ *
+ * Returns: (transfer none):
+ **/
 EvdPeer *
 evd_transport_lookup_peer (EvdTransport *self, const gchar *peer_id)
 {
   EvdPeerManager *peer_manager;
 
+  g_return_val_if_fail (EVD_IS_TRANSPORT (self), NULL);
+
+  if (peer_id == NULL)
+    return NULL;
+
   peer_manager = EVD_TRANSPORT_GET_INTERFACE (self)->peer_manager;
 
   return evd_peer_manager_lookup_peer (peer_manager, peer_id);
@@ -525,10 +564,10 @@ evd_transport_accept_peer (EvdTransport *self, EvdPeer *peer)
   g_return_val_if_fail (EVD_IS_PEER (peer), FALSE);
 
   iface = EVD_TRANSPORT_GET_INTERFACE (self);
-  if (iface->accept_peer == NULL || iface->accept_peer (self, peer))
-    return evd_transport_accept_peer_internal (self, peer);
+  if (iface->accept_peer != NULL)
+    return iface->accept_peer (self, peer);
   else
-    return FALSE;
+    return evd_transport_accept_peer_internal (self, peer);
 }
 
 gboolean
@@ -540,14 +579,14 @@ evd_transport_reject_peer (EvdTransport *self, EvdPeer *peer)
   g_return_val_if_fail (EVD_IS_PEER (peer), FALSE);
 
   iface = EVD_TRANSPORT_GET_INTERFACE (self);
-  if (iface->reject_peer == NULL || iface->reject_peer (self, peer))
+  if (iface->reject_peer != NULL)
     {
-      g_object_unref (peer);
-      return TRUE;
+      return iface->reject_peer (self, peer);
     }
   else
     {
-      return FALSE;
+      g_object_unref (peer);
+      return TRUE;
     }
 }
 
