@@ -88,7 +88,8 @@ enum
   PROP_0,
   PROP_BASE_PATH,
   PROP_SELECTOR,
-  PROP_LP_SERVICE
+  PROP_LP_SERVICE,
+  PROP_WEBSOCKET_SERVICE
 };
 
 static void     evd_web_transport_server_class_init           (EvdWebTransportServerClass *class);
@@ -119,11 +120,12 @@ static void     evd_web_transport_server_on_peer_closed       (EvdTransport *tra
                                                                gboolean      gracefully,
                                                                gpointer      user_data);
 
-static gboolean evd_web_transport_server_send                 (EvdTransport  *transport,
-                                                               EvdPeer       *peer,
-                                                               const gchar   *buffer,
-                                                               gsize          size,
-                                                               GError       **error);
+static gboolean evd_web_transport_server_send                 (EvdTransport    *transport,
+                                                               EvdPeer         *peer,
+                                                               const gchar     *buffer,
+                                                               gsize            size,
+                                                               EvdMessageType   type,
+                                                               GError         **error);
 
 static gboolean evd_web_transport_server_peer_is_connected    (EvdTransport *transport,
                                                                EvdPeer      *peer);
@@ -185,11 +187,19 @@ evd_web_transport_server_class_init (EvdWebTransportServerClass *class)
   g_object_class_install_property (obj_class, PROP_LP_SERVICE,
                                    g_param_spec_object ("lp-service",
                                                         "Long-Polling service",
-                                                        "Internal Long-Polling service used by this transport",
+                                                        "Internal Long-Polling service used by the transport",
                                                         EVD_TYPE_LONGPOLLING_SERVER,
                                                         G_PARAM_READABLE |
                                                         G_PARAM_STATIC_STRINGS));
 
+  g_object_class_install_property (obj_class, PROP_WEBSOCKET_SERVICE,
+                                   g_param_spec_object ("websocket-service",
+                                                        "Websocket service",
+                                                        "Internal Websocket service used by the transport",
+                                                        EVD_TYPE_WEBSOCKET_SERVER,
+                                                        G_PARAM_READABLE |
+                                                        G_PARAM_STATIC_STRINGS));
+
   g_type_class_add_private (obj_class, sizeof (EvdWebTransportServerPrivate));
 }
 
@@ -308,6 +318,10 @@ evd_web_transport_server_get_property (GObject    *obj,
       g_value_set_object (value, self->priv->lp);
       break;
 
+    case PROP_WEBSOCKET_SERVICE:
+      g_value_set_object (value, self->priv->ws);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
       break;
@@ -403,22 +417,34 @@ evd_web_transport_server_on_peer_closed (EvdTransport *transport,
 }
 
 static gboolean
-evd_web_transport_server_send (EvdTransport  *transport,
-                               EvdPeer       *peer,
-                               const gchar   *buffer,
-                               gsize          size,
-                               GError       **error)
+evd_web_transport_server_send (EvdTransport    *transport,
+                               EvdPeer         *peer,
+                               const gchar     *buffer,
+                               gsize            size,
+                               EvdMessageType   type,
+                               GError         **error)
 {
   EvdTransport *_transport;
 
   _transport = g_object_get_data (G_OBJECT (peer), PEER_DATA_KEY);
-  g_assert (EVD_IS_TRANSPORT (_transport));
-
-  return evd_transport_send (_transport,
-                             peer,
-                             buffer,
-                             size,
-                             error);
+  if (_transport == NULL)
+    {
+      g_set_error (error,
+                   G_IO_ERROR,
+                   G_IO_ERROR_NOT_INITIALIZED,
+                   "Failed to send data, peer is not associated with a "
+                   "sub-transport");
+      return FALSE;
+    }
+  else
+    {
+      return EVD_TRANSPORT_GET_INTERFACE (_transport)->send (_transport,
+                                                             peer,
+                                                             buffer,
+                                                             size,
+                                                             type,
+                                                             error);
+    }
 }
 
 static gboolean
@@ -857,6 +883,11 @@ evd_web_transport_server_set_selector (EvdWebTransportServer *self,
   g_object_ref (selector);
 }
 
+/**
+ * evd_web_transport_server_get_selector:
+ *
+ * Returns: (transfer none):
+ **/
 EvdWebSelector *
 evd_web_transport_server_get_selector (EvdWebTransportServer *self)
 {
